pub fn biased_entropy_rate_backend(
data: &[u8],
max_order: i64,
backend: &RateBackend,
) -> f64Expand description
Estimate biased/plugin entropy rate of data using the explicit rate backend.
pub fn biased_entropy_rate_backend(
data: &[u8],
max_order: i64,
backend: &RateBackend,
) -> f64Estimate biased/plugin entropy rate of data using the explicit rate backend.