pub fn entropy_rate_backend(
data: &[u8],
max_order: i64,
backend: &RateBackend,
) -> f64Expand description
Estimate entropy rate of data using the explicit rate backend.
pub fn entropy_rate_backend(
data: &[u8],
max_order: i64,
backend: &RateBackend,
) -> f64Estimate entropy rate of data using the explicit rate backend.