generate_bytes

Function generate_bytes 

pub fn generate_bytes(prompt: &[u8], bytes: usize, max_order: i64) -> Vec<u8> 
Generate a continuation from prompt using the current default context and GenerationConfig::default().

The default is deterministic frozen sampling with seed 42.