pub fn ncd_paths_backend(
x: &str,
y: &str,
backend: &CompressionBackend,
variant: NcdVariant,
) -> f64Expand description
Compute NCD for two file paths using an explicit compression backend.
pub fn ncd_paths_backend(
x: &str,
y: &str,
backend: &CompressionBackend,
variant: NcdVariant,
) -> f64Compute NCD for two file paths using an explicit compression backend.