pub fn parse_mixture_kind_name(kind: &str) -> Result<MixtureKind, String>Expand description
Parse a mixture kind name with the shared alias table used across CLI, Python, and WASM.
pub fn parse_mixture_kind_name(kind: &str) -> Result<MixtureKind, String>Parse a mixture kind name with the shared alias table used across CLI, Python, and WASM.