pub fn parse_mixture_schedule_name(
schedule: &str,
) -> Result<MixtureScheduleMode, String>Expand description
Parse a mixture schedule mode with the shared alias table used across CLI, Python, and WASM.
pub fn parse_mixture_schedule_name(
schedule: &str,
) -> Result<MixtureScheduleMode, String>Parse a mixture schedule mode with the shared alias table used across CLI, Python, and WASM.