pub struct InfotheoryCtx {
pub rate_backend: RateBackend,
pub compression_backend: CompressionBackend,
}Expand description
Reusable execution context holding default rate and compression backends.
Fields
rate_backend: RateBackendDefault rate backend for entropy/rate metrics.
compression_backend: CompressionBackendDefault compression backend for NCD/compression primitives.
Implementations
Sourceimpl InfotheoryCtx
impl InfotheoryCtx
Sourcepub fn new(
rate_backend: RateBackend,
compression_backend: CompressionBackend,
) -> Self
pub fn new( rate_backend: RateBackend, compression_backend: CompressionBackend, ) -> Self
Create a context from explicit rate and compression backends.
Sourcepub fn with_zpaq(method: impl Into<String>) -> Self
pub fn with_zpaq(method: impl Into<String>) -> Self
Create a context with ROSA+ rate backend and ZPAQ compression backend.
Sourcepub fn compress_size(&self, data: &[u8]) -> u64
pub fn compress_size(&self, data: &[u8]) -> u64
Compressed length of one byte slice under this context’s compressor.
Sourcepub fn compress_size_chain(&self, parts: &[&[u8]]) -> u64
pub fn compress_size_chain(&self, parts: &[&[u8]]) -> u64
Compressed length of chained slices under one stream.
Sourcepub fn rate_backend_session(
&self,
max_order: i64,
total_symbols: Option<u64>,
) -> Result<RateBackendSession, String>
pub fn rate_backend_session( &self, max_order: i64, total_symbols: Option<u64>, ) -> Result<RateBackendSession, String>
Create a stateful session for the active rate backend.
Sourcepub fn entropy_rate_bytes(&self, data: &[u8], max_order: i64) -> f64
pub fn entropy_rate_bytes(&self, data: &[u8], max_order: i64) -> f64
Entropy-rate estimate for data under this context’s rate backend.
Sourcepub fn biased_entropy_rate_bytes(&self, data: &[u8], max_order: i64) -> f64
pub fn biased_entropy_rate_bytes(&self, data: &[u8], max_order: i64) -> f64
Biased entropy-rate estimate (plugin variant) for data.
Sourcepub fn cross_entropy_rate_bytes(
&self,
test_data: &[u8],
train_data: &[u8],
max_order: i64,
) -> f64
pub fn cross_entropy_rate_bytes( &self, test_data: &[u8], train_data: &[u8], max_order: i64, ) -> f64
Cross entropy of test_data under model trained on train_data.
Sourcepub fn cross_entropy_bytes(
&self,
test_data: &[u8],
train_data: &[u8],
max_order: i64,
) -> f64
pub fn cross_entropy_bytes( &self, test_data: &[u8], train_data: &[u8], max_order: i64, ) -> f64
Cross entropy with order-0 fast-path fallback when max_order == 0.
Sourcepub fn joint_entropy_rate_bytes(
&self,
x: &[u8],
y: &[u8],
max_order: i64,
) -> f64
pub fn joint_entropy_rate_bytes( &self, x: &[u8], y: &[u8], max_order: i64, ) -> f64
Joint entropy-rate estimate H(X,Y) under aligned-prefix semantics.
Sourcepub fn conditional_entropy_rate_bytes(
&self,
x: &[u8],
y: &[u8],
max_order: i64,
) -> f64
pub fn conditional_entropy_rate_bytes( &self, x: &[u8], y: &[u8], max_order: i64, ) -> f64
Conditional entropy-rate estimate H(X|Y).
Sourcepub fn cross_entropy_conditional_chain(
&self,
prefix_parts: &[&[u8]],
data: &[u8],
) -> f64
pub fn cross_entropy_conditional_chain( &self, prefix_parts: &[&[u8]], data: &[u8], ) -> f64
Compute H(data | prefix_parts) by conditioning the active rate backend
on an explicit prefix chain.
Sourcepub fn generate_bytes(
&self,
prompt: &[u8],
bytes: usize,
max_order: i64,
) -> Vec<u8> ⓘ
pub fn generate_bytes( &self, prompt: &[u8], bytes: usize, max_order: i64, ) -> Vec<u8> ⓘ
Generate a continuation from prompt with GenerationConfig::default().
The default is deterministic frozen sampling with seed 42.
Sourcepub fn generate_bytes_with_config(
&self,
prompt: &[u8],
bytes: usize,
max_order: i64,
config: GenerationConfig,
) -> Vec<u8> ⓘ
pub fn generate_bytes_with_config( &self, prompt: &[u8], bytes: usize, max_order: i64, config: GenerationConfig, ) -> Vec<u8> ⓘ
Generate a continuation from prompt using an explicit generation config.
Sourcepub fn generate_bytes_conditional_chain(
&self,
prefix_parts: &[&[u8]],
bytes: usize,
max_order: i64,
) -> Vec<u8> ⓘ
pub fn generate_bytes_conditional_chain( &self, prefix_parts: &[&[u8]], bytes: usize, max_order: i64, ) -> Vec<u8> ⓘ
Generate a continuation after conditioning on an explicit chain of prefix parts.
Sourcepub fn generate_bytes_conditional_chain_with_config(
&self,
prefix_parts: &[&[u8]],
bytes: usize,
max_order: i64,
config: GenerationConfig,
) -> Vec<u8> ⓘ
pub fn generate_bytes_conditional_chain_with_config( &self, prefix_parts: &[&[u8]], bytes: usize, max_order: i64, config: GenerationConfig, ) -> Vec<u8> ⓘ
Generate a continuation after conditioning on an explicit chain of prefix parts.
Sourcepub fn ncd_bytes(&self, x: &[u8], y: &[u8], variant: NcdVariant) -> f64
pub fn ncd_bytes(&self, x: &[u8], y: &[u8], variant: NcdVariant) -> f64
NCD between byte slices using this context’s compression backend.
Sourcepub fn mutual_information_rate_bytes(
&self,
x: &[u8],
y: &[u8],
max_order: i64,
) -> f64
pub fn mutual_information_rate_bytes( &self, x: &[u8], y: &[u8], max_order: i64, ) -> f64
Rate-backend mutual information estimate.
Sourcepub fn mutual_information_bytes(
&self,
x: &[u8],
y: &[u8],
max_order: i64,
) -> f64
pub fn mutual_information_bytes( &self, x: &[u8], y: &[u8], max_order: i64, ) -> f64
Mutual information with max_order == 0 marginal fast-path.
Sourcepub fn conditional_entropy_bytes(
&self,
x: &[u8],
y: &[u8],
max_order: i64,
) -> f64
pub fn conditional_entropy_bytes( &self, x: &[u8], y: &[u8], max_order: i64, ) -> f64
Conditional entropy with aligned-prefix semantics.
Sourcepub fn ned_bytes(&self, x: &[u8], y: &[u8], max_order: i64) -> f64
pub fn ned_bytes(&self, x: &[u8], y: &[u8], max_order: i64) -> f64
Normalized entropy distance (NED) under this context.
Sourcepub fn ned_cons_bytes(&self, x: &[u8], y: &[u8], max_order: i64) -> f64
pub fn ned_cons_bytes(&self, x: &[u8], y: &[u8], max_order: i64) -> f64
Conservative NED normalization variant.
Sourcepub fn nte_bytes(&self, x: &[u8], y: &[u8], max_order: i64) -> f64
pub fn nte_bytes(&self, x: &[u8], y: &[u8], max_order: i64) -> f64
Normalized transform effort (NTE) under this context.
Sourcepub fn intrinsic_dependence_bytes(&self, data: &[u8], max_order: i64) -> f64
pub fn intrinsic_dependence_bytes(&self, data: &[u8], max_order: i64) -> f64
Intrinsic dependence score in [0,1].